Diff
Modified: trunk/CMakeLists.txt (198085 => 198086)
--- trunk/CMakeLists.txt 2016-03-13 22:28:11 UTC (rev 198085)
+++ trunk/CMakeLists.txt 2016-03-13 22:30:13 UTC (rev 198086)
@@ -19,7 +19,14 @@
# -----------------------------------------------------------------------------
# Determine which port will be built
# -----------------------------------------------------------------------------
-set(ALL_PORTS Efl GTK AppleWin WinCairo Mac)
+set(ALL_PORTS
+ AppleWin
+ Efl
+ GTK
+ JSCOnly
+ Mac
+ WinCairo
+)
set(PORT "NOPORT" CACHE STRING "choose which WebKit port to build (one of ${ALL_PORTS})")
list(FIND ALL_PORTS ${PORT} RET)
Modified: trunk/ChangeLog (198085 => 198086)
--- trunk/ChangeLog 2016-03-13 22:28:11 UTC (rev 198085)
+++ trunk/ChangeLog 2016-03-13 22:30:13 UTC (rev 198086)
@@ -1,3 +1,16 @@
+2016-03-13 Konstantin Tokarev <[email protected]>
+
+ Added new port JSCOnly.
+ https://bugs.webkit.org/show_bug.cgi?id=154512
+
+ Reviewed by Michael Catanzaro.
+
+ This port allows to build _javascript_Core engine with minimal
+ dependencies.
+
+ * CMakeLists.txt:
+ * Source/cmake/OptionsJSCOnly.cmake: Added.
+
2016-03-12 Myles C. Maxfield <[email protected]>
Delete dead SVG Font code
Modified: trunk/Source/_javascript_Core/ChangeLog (198085 => 198086)
--- trunk/Source/_javascript_Core/ChangeLog 2016-03-13 22:28:11 UTC (rev 198085)
+++ trunk/Source/_javascript_Core/ChangeLog 2016-03-13 22:30:13 UTC (rev 198086)
@@ -1,3 +1,15 @@
+2016-03-13 Konstantin Tokarev <[email protected]>
+
+ Added new port JSCOnly.
+ https://bugs.webkit.org/show_bug.cgi?id=154512
+
+ Reviewed by Michael Catanzaro.
+
+ This port allows to build _javascript_Core engine with minimal
+ dependencies.
+
+ * PlatformJSCOnly.cmake: Added.
+
2016-03-12 Mark Lam <[email protected]>
http://kangax.github.io/compat-table/esnext/ crashes reliably.
Added: trunk/Source/_javascript_Core/PlatformJSCOnly.cmake (0 => 198086)
--- trunk/Source/_javascript_Core/PlatformJSCOnly.cmake (rev 0)
+++ trunk/Source/_javascript_Core/PlatformJSCOnly.cmake 2016-03-13 22:30:13 UTC (rev 198086)
@@ -0,0 +1,14 @@
+add_definitions(-DSTATICALLY_LINKED_WITH_WTF)
+
+list(APPEND _javascript_Core_INCLUDE_DIRECTORIES
+ "${WTF_DIR}"
+)
+
+if (USE_GLIB)
+ list(APPEND _javascript_Core_SYSTEM_INCLUDE_DIRECTORIES
+ ${GLIB_INCLUDE_DIRS}
+ )
+ list(APPEND _javascript_Core_LIBRARIES
+ ${GLIB_LIBRARIES}
+ )
+endif ()
Modified: trunk/Source/WTF/ChangeLog (198085 => 198086)
--- trunk/Source/WTF/ChangeLog 2016-03-13 22:28:11 UTC (rev 198085)
+++ trunk/Source/WTF/ChangeLog 2016-03-13 22:30:13 UTC (rev 198086)
@@ -1,3 +1,18 @@
+2016-03-13 Konstantin Tokarev <[email protected]>
+
+ Added new port JSCOnly.
+ https://bugs.webkit.org/show_bug.cgi?id=154512
+
+ Reviewed by Michael Catanzaro.
+
+ This port allows to build _javascript_Core engine with minimal
+ dependencies.
+
+ * wtf/PlatformJSCOnly.cmake: Added.
+ * wtf/none/MainThreadNone.cpp: Added.
+ * wtf/none/RunLoopNone.cpp: Added.
+ * wtf/none/WorkQueueNone.cpp: Added.
+
2016-03-13 David Kilzer <[email protected]>
REGRESSION (r198079): Windows build broke because of "%PRId64" format specifier
Added: trunk/Source/WTF/wtf/PlatformJSCOnly.cmake (0 => 198086)
--- trunk/Source/WTF/wtf/PlatformJSCOnly.cmake (rev 0)
+++ trunk/Source/WTF/wtf/PlatformJSCOnly.cmake 2016-03-13 22:30:13 UTC (rev 198086)
@@ -0,0 +1,26 @@
+if (LOWERCASE_EVENTLOOP_TYPE STREQUAL "glib")
+ list(APPEND WTF_SOURCES
+ glib/GRefPtr.cpp
+ glib/MainThreadGLib.cpp
+ glib/RunLoopGLib.cpp
+ glib/WorkQueueGLib.cpp
+ )
+ list(APPEND WTF_SYSTEM_INCLUDE_DIRECTORIES
+ ${GLIB_INCLUDE_DIRS}
+ )
+ list(APPEND WTF_LIBRARIES
+ ${GLIB_GIO_LIBRARIES}
+ ${GLIB_GOBJECT_LIBRARIES}
+ ${GLIB_LIBRARIES}
+ )
+else ()
+ list(APPEND WTF_SOURCES
+ none/MainThreadNone.cpp
+ none/RunLoopNone.cpp
+ none/WorkQueueNone.cpp
+ )
+endif ()
+
+list(APPEND WTF_LIBRARIES
+ ${CMAKE_THREAD_LIBS_INIT}
+)
Modified: trunk/Source/WTF/wtf/WorkQueue.h (198085 => 198086)
--- trunk/Source/WTF/wtf/WorkQueue.h 2016-03-13 22:28:11 UTC (rev 198085)
+++ trunk/Source/WTF/wtf/WorkQueue.h 2016-03-13 22:30:13 UTC (rev 198086)
@@ -38,12 +38,12 @@
#include <dispatch/dispatch.h>
#endif
-#if PLATFORM(GTK)
+#if PLATFORM(EFL)
+#include <DispatchQueueEfl.h>
+#elif USE(GLIB)
#include <wtf/Condition.h>
#include <wtf/RunLoop.h>
#include <wtf/glib/GRefPtr.h>
-#elif PLATFORM(EFL)
-#include <DispatchQueueEfl.h>
#elif OS(WINDOWS)
#include <wtf/HashMap.h>
#include <wtf/Vector.h>
@@ -74,11 +74,11 @@
WTF_EXPORT_PRIVATE static void concurrentApply(size_t iterations, const std::function<void (size_t index)>&);
-#if PLATFORM(GTK)
- RunLoop& runLoop() const { return *m_runLoop; }
-#elif PLATFORM(EFL)
+#if PLATFORM(EFL)
void registerSocketEventHandler(int, std::function<void ()>);
void unregisterSocketEventHandler(int);
+#elif USE(GLIB)
+ RunLoop& runLoop() const { return *m_runLoop; }
#elif OS(DARWIN)
dispatch_queue_t dispatchQueue() const { return m_dispatchQueue; }
#endif
@@ -102,15 +102,15 @@
static DWORD WINAPI unregisterWaitAndDestroyItemCallback(void* context);
#endif
-#if PLATFORM(GTK)
+#if PLATFORM(EFL)
+ RefPtr<DispatchQueue> m_dispatchQueue;
+#elif USE(GLIB)
ThreadIdentifier m_workQueueThread;
Lock m_initializeRunLoopConditionMutex;
Condition m_initializeRunLoopCondition;
RunLoop* m_runLoop;
Lock m_terminateRunLoopConditionMutex;
Condition m_terminateRunLoopCondition;
-#elif PLATFORM(EFL)
- RefPtr<DispatchQueue> m_dispatchQueue;
#elif OS(DARWIN)
static void executeFunction(void*);
dispatch_queue_t m_dispatchQueue;
Added: trunk/Source/WTF/wtf/none/MainThreadNone.cpp (0 => 198086)
--- trunk/Source/WTF/wtf/none/MainThreadNone.cpp (rev 0)
+++ trunk/Source/WTF/wtf/none/MainThreadNone.cpp 2016-03-13 22:30:13 UTC (rev 198086)
@@ -0,0 +1,39 @@
+/*
+ * Copyright (C) 2016 Konstantin Tokavev <[email protected]>
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 1. Redistributions of source code must retain the above copyright
+ * notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ * notice, this list of conditions and the following disclaimer in the
+ * documentation and/or other materials provided with the distribution.
+ *
+ * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
+ * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+ * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR
+ * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+ * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+ * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
+ * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
+ * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+ * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
+#include "config.h"
+#include "MainThread.h"
+
+namespace WTF {
+
+void initializeMainThreadPlatform()
+{
+}
+
+void scheduleDispatchFunctionsOnMainThread()
+{
+}
+
+}
Added: trunk/Source/WTF/wtf/none/RunLoopNone.cpp (0 => 198086)
--- trunk/Source/WTF/wtf/none/RunLoopNone.cpp (rev 0)
+++ trunk/Source/WTF/wtf/none/RunLoopNone.cpp 2016-03-13 22:30:13 UTC (rev 198086)
@@ -0,0 +1,75 @@
+/*
+ * Copyright (C) 2016 Konstantin Tokavev <[email protected]>
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 1. Redistributions of source code must retain the above copyright
+ * notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ * notice, this list of conditions and the following disclaimer in the
+ * documentation and/or other materials provided with the distribution.
+ *
+ * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
+ * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+ * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR
+ * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+ * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+ * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
+ * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
+ * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+ * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
+#include "config.h"
+#include "RunLoop.h"
+
+namespace WTF {
+
+RunLoop::RunLoop()
+{
+}
+
+RunLoop::~RunLoop()
+{
+}
+
+void RunLoop::run()
+{
+}
+
+void RunLoop::stop()
+{
+}
+
+void RunLoop::wakeUp()
+{
+ ASSERT_NOT_REACHED();
+}
+
+RunLoop::TimerBase::TimerBase(RunLoop& runLoop)
+ : m_runLoop(runLoop)
+{
+}
+
+RunLoop::TimerBase::~TimerBase()
+{
+ stop();
+}
+
+void RunLoop::TimerBase::start(double, bool)
+{
+}
+
+void RunLoop::TimerBase::stop()
+{
+}
+
+bool RunLoop::TimerBase::isActive() const
+{
+ return false;
+}
+
+} // namespace WTF
Added: trunk/Source/WTF/wtf/none/WorkQueueNone.cpp (0 => 198086)
--- trunk/Source/WTF/wtf/none/WorkQueueNone.cpp (rev 0)
+++ trunk/Source/WTF/wtf/none/WorkQueueNone.cpp 2016-03-13 22:30:13 UTC (rev 198086)
@@ -0,0 +1,45 @@
+/*
+ * Copyright (C) 2016 Konstantin Tokavev <[email protected]>
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 1. Redistributions of source code must retain the above copyright
+ * notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ * notice, this list of conditions and the following disclaimer in the
+ * documentation and/or other materials provided with the distribution.
+ *
+ * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
+ * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+ * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR
+ * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+ * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+ * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
+ * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
+ * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+ * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
+#include "config.h"
+#include "WorkQueue.h"
+
+void WorkQueue::platformInitialize(const char*, Type, QOS)
+{
+}
+
+void WorkQueue::platformInvalidate()
+{
+}
+
+void WorkQueue::dispatch(std::function<void()>)
+{
+ ASSERT_NOT_REACHED();
+}
+
+void WorkQueue::dispatchAfter(std::chrono::nanoseconds, std::function<void()>)
+{
+ ASSERT_NOT_REACHED();
+}
Added: trunk/Source/cmake/OptionsJSCOnly.cmake (0 => 198086)
--- trunk/Source/cmake/OptionsJSCOnly.cmake (rev 0)
+++ trunk/Source/cmake/OptionsJSCOnly.cmake 2016-03-13 22:30:13 UTC (rev 198086)
@@ -0,0 +1,66 @@
+find_package(ICU REQUIRED)
+find_package(Threads REQUIRED)
+
+set(PROJECT_VERSION_MAJOR 1)
+set(PROJECT_VERSION_MINOR 0)
+set(PROJECT_VERSION_MICRO 0)
+set(PROJECT_VERSION ${PROJECT_VERSION_MAJOR}.${PROJECT_VERSION_MINOR}.${PROJECT_VERSION_MICRO})
+
+WEBKIT_OPTION_BEGIN()
+WEBKIT_OPTION_DEFINE(ENABLE_STATIC_JSC "Whether to build _javascript_Core as a static library." PUBLIC OFF)
+WEBKIT_OPTION_DEFAULT_PORT_VALUE(ENABLE_FTL_JIT PUBLIC ON)
+WEBKIT_OPTION_END()
+
+set(ALL_EVENTLOOP_TYPES
+ GLib
+ None
+)
+
+if (UNIX AND NOT APPLE)
+ set(DEFAULT_EVENTLOOP_TYPE "GLib")
+else ()
+ # TODO: Use native Mac and Win implementations
+ set(DEFAULT_EVENTLOOP_TYPE "None")
+endif ()
+
+set(EVENTLOOP_TYPE ${DEFAULT_EVENTLOOP_TYPE} CACHE STRING "Implementation of event loop to be used in _javascript_Core (one of ${ALL_EVENTLOOP_TYPES})")
+
+set(ENABLE_WEBKIT OFF)
+set(ENABLE_WEBKIT2 OFF)
+set(ENABLE_API_TESTS OFF)
+
+if (WTF_CPU_X86 OR WTF_CPU_X86_64)
+ set(WTF_USE_UDIS86 1)
+endif ()
+
+if (ENABLE_STATIC_JSC)
+ set(_javascript_Core_LIBRARY_TYPE STATIC)
+endif ()
+
+string(TOLOWER ${EVENTLOOP_TYPE} LOWERCASE_EVENTLOOP_TYPE)
+if (LOWERCASE_EVENTLOOP_TYPE STREQUAL "glib")
+ find_package(GLIB 2.36 REQUIRED COMPONENTS gio gobject)
+ SET_AND_EXPOSE_TO_BUILD(USE_GLIB 1)
+endif ()
+
+# From OptionsGTK.cmake
+if (CMAKE_MAJOR_VERSION LESS 3)
+ # Before CMake 3 it was necessary to use a build script instead of using cmake --build directly
+ # to preserve colors and pretty-printing.
+
+ build_command(COMMAND_LINE_TO_BUILD)
+ # build_command unconditionally adds -i (ignore errors) for make, and there's
+ # no reasonable way to turn that off, so we just replace it with -k, which has
+ # the same effect, except that the return code will indicate that an error occurred.
+ # See: http://www.cmake.org/cmake/help/v3.0/command/build_command.html
+ string(REPLACE " -i" " -k" COMMAND_LINE_TO_BUILD ${COMMAND_LINE_TO_BUILD})
+ file(WRITE
+ ${CMAKE_BINARY_DIR}${CMAKE_FILES_DIRECTORY}/build.sh
+ "#!/bin/sh\n"
+ "${COMMAND_LINE_TO_BUILD} $@"
+ )
+ file(COPY ${CMAKE_BINARY_DIR}${CMAKE_FILES_DIRECTORY}/build.sh
+ DESTINATION ${CMAKE_BINARY_DIR}
+ FILE_PERMISSIONS OWNER_READ OWNER_WRITE OWNER_EXECUTE GROUP_READ GROUP_EXECUTE
+ )
+endif ()
Modified: trunk/Tools/ChangeLog (198085 => 198086)
--- trunk/Tools/ChangeLog 2016-03-13 22:28:11 UTC (rev 198085)
+++ trunk/Tools/ChangeLog 2016-03-13 22:30:13 UTC (rev 198086)
@@ -1,3 +1,23 @@
+2016-03-13 Konstantin Tokarev <[email protected]>
+
+ Added new port JSCOnly.
+ https://bugs.webkit.org/show_bug.cgi?id=154512
+
+ Reviewed by Michael Catanzaro.
+
+ This port allows to build _javascript_Core engine with minimal
+ dependencies.
+
+ * Scripts/build-jsc:
+ * Scripts/webkitdirs.pm:
+ (argumentsForConfiguration):
+ (executableProductDir):
+ (determinePortName):
+ (isJSCOnly):
+ (wrapperPrefixIfNeeded):
+ (generateBuildSystemFromCMakeProject):
+ (buildCMakeGeneratedProject):
+
2016-03-13 David Kilzer <[email protected]>
TestWebKitAPI: fix linker warnings
Modified: trunk/Tools/Scripts/build-jsc (198085 => 198086)
--- trunk/Tools/Scripts/build-jsc 2016-03-13 22:28:11 UTC (rev 198085)
+++ trunk/Tools/Scripts/build-jsc 2016-03-13 22:30:13 UTC (rev 198086)
@@ -42,7 +42,7 @@
my $shouldRunStaticAnalyzer = 0;
my $coverageSupport = 0;
my $showHelp = 0;
-my $ftlJIT = int(isAppleMacWebKit() && !willUseIOSSimulatorSDK() || isX86_64() && (isGtk() || isEfl()));
+my $ftlJIT = int(isAppleMacWebKit() && !willUseIOSSimulatorSDK() || isX86_64() && (isGtk() || isEfl() || isJSCOnly()));
my $forceCLoop = 0;
my $cli = 0;
my $makeArgs = "";
Modified: trunk/Tools/Scripts/webkitdirs.pm (198085 => 198086)
--- trunk/Tools/Scripts/webkitdirs.pm 2016-03-13 22:28:11 UTC (rev 198085)
+++ trunk/Tools/Scripts/webkitdirs.pm 2016-03-13 22:30:13 UTC (rev 198086)
@@ -101,6 +101,7 @@
Efl => "Efl",
iOS => "iOS",
Mac => "Mac",
+ JSCOnly => "JSCOnly",
WinCairo => "WinCairo",
Unknown => "Unknown"
};
@@ -448,6 +449,7 @@
push(@args, '--64-bit') if (isWin64());
push(@args, '--gtk') if isGtk();
push(@args, '--efl') if isEfl();
+ push(@args, '--jsc-only') if isJSCOnly();
push(@args, '--wincairo') if isWinCairo();
push(@args, '--inspector-frontend') if isInspectorFrontend();
return @args;
@@ -644,7 +646,7 @@
my $productDirectory = productDir();
my $binaryDirectory;
- if (isEfl() || isGtk()) {
+ if (isEfl() || isGtk() || isJSCOnly()) {
$binaryDirectory = "bin";
} elsif (isAnyWindows()) {
$binaryDirectory = isWin64() ? "bin64" : "bin32";
@@ -1045,6 +1047,7 @@
my %argToPortName = (
efl => Efl,
gtk => GTK,
+ 'jsc-only' => JSCOnly,
wincairo => WinCairo
);
@@ -1075,6 +1078,7 @@
my $portsChoice = join "\n\t", qw(
--efl
--gtk
+ --jsc-only
);
die "Please specify which WebKit port to build using one of the following options:"
. "\n\t$portsChoice\n";
@@ -1102,6 +1106,11 @@
return portName() eq GTK;
}
+sub isJSCOnly()
+{
+ return portName() eq JSCOnly;
+}
+
# Determine if this is debian, ubuntu, linspire, or something similar.
sub isDebianBased()
{
@@ -1831,7 +1840,7 @@
sub wrapperPrefixIfNeeded()
{
- if (isAnyWindows()) {
+ if (isAnyWindows() || isJSCOnly()) {
return ();
}
if (isAppleMacWebKit()) {
@@ -1984,8 +1993,8 @@
push @args, '-G "Visual Studio 14 2015 Win64"';
}
- # GTK+ has a production mode, but build-webkit should always use developer mode.
- push @args, "-DDEVELOPER_MODE=ON" if isEfl() || isGtk();
+ # Some ports have production mode, but build-webkit should always use developer mode.
+ push @args, "-DDEVELOPER_MODE=ON" if isEfl() || isGtk() || isJSCOnly();
# Don't warn variables which aren't used by cmake ports.
push @args, "--no-warn-unused-cli";
@@ -2023,8 +2032,8 @@
my @args = ("--build", $buildPath, "--config", $config);
push @args, ("--", $makeArgs) if $makeArgs;
- # GTK can use a build script to preserve colors and pretty-printing.
- if (isGtk() && -e "$buildPath/build.sh") {
+ # GTK and JSCOnly can use a build script to preserve colors and pretty-printing.
+ if ((isGtk() || isJSCOnly()) && -e "$buildPath/build.sh") {
chdir "$buildPath" or die;
$command = "$buildPath/build.sh";
@args = ($makeArgs);